import logging

if __name__ == "__main__":
    logging.basicConfig(level=logging.INFO)
    logger = logging.getLogger()
    logger.warning('This is a dummy placeholder for the SparkBeyond Python SDK.'
                   'The actual SDK can be installed directly from your Discovery Platform server.'
                   'For further information, please contact support@sparkbeyond.com')



from setuptools import setup

setup(
  name='sparkbeyond',
  packages=['sparkbeyond'],
  version='1.0.3',
  license='MIT',
  description='Dummy package for SparkBeyond Python SDK',
  maintainer='Sparkbeyond',
  maintainer_email='admin@sparkbeyond.com',
  url='https://www.sparkbeyond.com/',
  keywords=['sparkbeyond'],
  classifiers=[
    # Pick your license as you wish
    'License :: OSI Approved :: MIT License',

    # Specify the Python versions you support here. In particular, ensure
    # that you indicate whether you support Python 2, Python 3 or both.
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3.6'],
)
